``sbijax.nn``
=============

.. currentmodule:: sbijax.nn

----

``sbijax.nn`` contains utility functions and classes to construct neural
networks and normalizing flows.

.. autosummary::
    make_affine_maf
    make_surjective_affine_maf
    make_resnet
    make_ccnf
    make_snass_net
    make_snasss_net


.. autofunction:: make_affine_maf

.. autofunction:: make_surjective_affine_maf

.. autofunction:: make_resnet

.. autofunction:: make_ccnf

.. autofunction:: make_snass_net

.. autofunction:: make_snasss_net
